#!/bin/bash
# 
# Description
# Lists of servers by function and environment
# This script sets variables used by the uc4_env.sh and uc4_functions.sh scripts.
#
# Usage
# Source this script from .bashrc or other scripts
#
# Revision history
# Version	Date		Author		Comments
# 1.0		2021.03.01	Michael Lowry	Initial public version

# Set shell options
# extglob enables lists like '@(a|b|c)'
shopt -s extglob

# Lists of servers in each staging environment
EXP_SERVERS='@(ae-exp-a|ae-exp-b)'
EXP2_SERVERS='@(ae-exp2-a|ae-exp2-b)'
DEV_SERVERS='@(ae-dev-a|ae-dev-b)'
ITE_SERVERS='@(ae-ite-a|ae-ite-b)'
PROD_SERVERS='@(ae-ite-a|ae-ite-b)'

# Lists of servers in each functional group
UC4_AE_SERVERS='@(ae-exp-a|ae-exp-b|ae-exp2-a|ae-exp2-b|ae-dev-a|ae-dev-b|ae-ite-a|ae-ite-b|ae-ite-a|ae-ite-b)'

# Lists of primary and secondary members of clusters
PRIMARY_SERVERS='@(ae-exp-a|ae-exp2-a|ae-dev-a|ae-ite-a|ae-ite-a)'
SECONDARY_SERVERS='@(ae-exp-b|ae-exp2-b|ae-dev-b|ae-ite-b|ae-ite-b|)'

# Get server name
SERVER=$(uname -n)

# Determine the staging environment
case "$SERVER" in
    $PROD_SERVERS)              # Production
        SERVER_ENVIRONMENT=PROD
	ENV_ABBREV=p
        ;;
    $ITE_SERVERS)               # Integrated Test Environment (ITE), a.k.a. TEST or TRAIN
        SERVER_ENVIRONMENT=ITE
	ENV_ABBREV=t
        ;;
    $DEV_SERVERS)               # Development
        SERVER_ENVIRONMENT=DEV
	ENV_ABBREV=d
        ;;
    $EXP_SERVERS)               # Experimental
        SERVER_ENVIRONMENT=EXP
	ENV_ABBREV=x
        ;;
    $EXP2_SERVERS)               # Experimental 2
        SERVER_ENVIRONMENT=EXP2
	ENV_ABBREV=x
        ;;
    *)                          # Unkownn staging environment
        SERVER_ENVIRONMENT=UNKNOWN
        ;;
esac

# Determine the functional group
case "$SERVER" in
    $UC4_AE_SERVERS)            # UC4 Automation Engine
        SERVER_FUNCTION=UC4_AE
        ;;
    *)                          # Unkownn functional group
        SERVER_FUNCTION=UNKNOWN
        ;;
esac

# For servers that are part of a cluster, determine
# whether the server is the primary or secondary member

case "$SERVER" in
    $PRIMARY_SERVERS)
        SERVER_CLUSTER_MEMBER=1
        SERVER_NODE="A"
        ;;
    $SECONDARY_SERVERS)
        SERVER_CLUSTER_MEMBER=2
        SERVER_NODE="B"
        ;;
esac
